Package: PP
Type: Package
Title: Person Parameter Estimation
Version: 0.6.4-1
Date: 2026-04-21
Authors@R: c(
        person(given = "Jan", 
         family = "Steinfeld", 
         email = "jan.d.steinfeld@gmail.com", 
         role = c("cre","aut"),
         comment = c(ORCID = "0000-0001-9853-8260")
         ),
         person(given = "Manuel", 
         family = "Reif", 
         email = "manuel.reif@gmail.com", 
         role = c("aut")
         )
    )
Author: Jan Steinfeld [cre, aut] (ORCID:
    <https://orcid.org/0000-0001-9853-8260>),
  Manuel Reif [aut]
Maintainer: Jan Steinfeld <jan.d.steinfeld@gmail.com>
Description: The PP package includes estimation of (MLE, WLE, MAP, EAP, ROBUST)
    person parameters for the 1,2,3,4-PL model and the GPCM (generalized
    partial credit model). The parameters are estimated under the assumption
    that the item parameters are known and fixed. The package is useful e.g. in
    the case that items from an item pool / item bank with known item parameters
    are administered to a new population of test-takers and an ability
    estimation for every test-taker is needed.
URL: https://github.com/jansteinfeld/PP
BugReports: https://github.com/jansteinfeld/PP/issues
License: GPL-3
LazyLoad: yes
LazyData: true
VignetteBuilder: knitr
Depends: R (>= 3.0)
Encoding: UTF-8
Suggests: testthat, roxygen2, knitr, eRm, data.table, prettydoc,
        rmarkdown
Imports: Rcpp (>= 0.11.2)
LinkingTo: Rcpp
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-04-21 12:55:51 UTC; steinfeldj
Repository: CRAN
Date/Publication: 2026-04-21 13:22:09 UTC
Built: R 4.4.3; x86_64-apple-darwin20; 2026-04-21 14:17:52 UTC; unix
Archs: PP.so.dSYM
