# Generated by roxygen2: do not edit by hand

S3method(JKpp,fourpl)
S3method(JKpp,gpcm)
S3method(JKpp,gpcm4pl)
S3method(PPass,Rm)
S3method(PPass,default)
S3method(PV,fourpl)
S3method(PV,gpcm)
S3method(PV,gpcm4pl)
S3method(Pfit,fourpl)
S3method(Pfit,gpcm)
S3method(print,jk)
S3method(print,ppeo)
S3method(print,pv)
S3method(summary,jk)
S3method(summary,ppeo)
S3method(summary,pv)
export(JKpp)
export(PP_4pl)
export(PP_gpcm)
export(PPall)
export(PPass)
export(PV)
export(Pfit)
export(Pfit_lzstarmix)
export(findmodel)
export(lzstar_mixed)
export(print_personfit_summary)
export(sim_4pl)
export(sim_gpcm)
import(graphics)
import(stats)
import(utils)
importFrom(Rcpp,evalCpp)
importFrom(Rcpp,sourceCpp)
useDynLib(PP)
useDynLib(PP, .registration = TRUE)
