% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lzstar_mixed.R
\name{Pfit_lzstarmix}
\alias{Pfit_lzstarmix}
\title{Universal PPall person-fit wrapper with full diagnostics}
\usage{
Pfit_lzstarmix(
  respm,
  ppobj,
  model2est = NULL,
  orig_thres = NULL,
  orig_slopes = NULL,
  orig_lowerA = NULL
)
}
\arguments{
\item{respm}{Response matrix.}

\item{ppobj}{PPall output.}

\item{model2est}{Original model specification.}

\item{orig_thres}{Original thres input to PPall.}

\item{orig_slopes}{Original slopes input.}

\item{orig_lowerA}{Original lowerA input.}
}
\description{
Universal PPall person-fit wrapper with full diagnostics
}
\details{
This wrapper tries multiple extraction strategies and then calls
\code{lzstar_mixed()} without changing the core calculation.
}
